@@ -1,6 +1,6 @@
 /* libpq.c
 
-   Copyright (C) 2003-2015, 2017 Thien-Thi Nguyen
+   Copyright (C) 2003-2015, 2017, 2020 Thien-Thi Nguyen
    Portions Copyright (C) 1999, 2000 Ian Grant
 
    This file is part of Guile-PG.
@@ -1324,6 +1324,21 @@ This is basically
 
 @noindent
 which yields 40725 for PostgreSQL 4.7.25, for example.
+However, for PostgreSQL 10 and later, the number represents
+
+@example
+(+ (* 10000 @var{major}) @var{minor})
+@end example
+
+@noindent
+although the documentation recommends considering it to be
+
+@example
+(+ (* 100 @var{effective-major}) @var{minor})
+@end example
+
+@noindent
+for the purposes of feature comparison.
 Return @code{#f} if @var{conn} is closed.  */)
 {
 #define FUNC_NAME s_pg_server_version
