@@ -1,6 +1,6 @@
 ;;; postgres-gxrepl.scm --- like psql(1) but still evolving
 
-;; Copyright (C) 2005, 2006, 2008, 2009, 2011 Thien-Thi Nguyen
+;; Copyright (C) 2005, 2006, 2008, 2009, 2011, 2017 Thien-Thi Nguyen
 ;;
 ;; This file is part of Guile-PG.
 ;;
@@ -39,6 +39,13 @@
   #:use-module ((database postgres-qcons)
                 #:select (parse+make-SELECT-tree
                           sql-command<-trees))
+  #:use-module ((srfi srfi-13) #:select (string-index
+                                         string-take
+                                         string-prefix?
+                                         string-suffix?
+                                         string-skip
+                                         string-concatenate-reverse
+                                         substring/shared))
   #:autoload (ice-9 pretty-print) (pretty-print))
 
 (define *comma-commands* '())
@@ -66,19 +73,19 @@
           (else "(no docs)")))
   (for-display
    (cond ((null? command)
-          (apply string-append
-                 (map (lambda (ent)
-                        (fs "~A~A-- ~A~A"
-                            (car ent)
-                            #\ht
-                            (get-doc (cdr ent)
-                                     (lambda (doc)
-                                       (cond ((string-index doc #\nl)
-                                              => (lambda (cut)
-                                                   (substring doc 0 cut)))
-                                             (else doc))))
-                            #\newline))
-                      (reverse *comma-commands*))))
+          (string-concatenate-reverse
+           (map (lambda (ent)
+                  (fs "~A~A-- ~A~A"
+                      (car ent)
+                      #\ht
+                      (get-doc (cdr ent)
+                               (lambda (doc)
+                                 (cond ((string-index doc #\nl)
+                                        => (lambda (cut)
+                                             (string-take doc cut)))
+                                       (else doc))))
+                      #\newline))
+                *comma-commands*)))
          ((assq-ref *comma-commands* (car command))
           => (lambda (proc)
                (get-doc proc identity)))
@@ -383,9 +390,9 @@ specified by \",fix\".  Keywords without related expressions are ignored."
                    (loop so-far prompt))
                   ((zero? len)
                    (loop line (make-prompt #:ellipse)))
-                  ((char=? #\, (string-ref line 0))
+                  ((string-prefix? "," line)
                    (let ((cmd (with-input-from-string
-                                  (fs "(~A)" (substring line 1))
+                                  (fs "(~A)" (substring/shared line 1))
                                 read)))
                      (cond ((assq-ref *comma-commands* (car cmd))
                             => (lambda (proc)
@@ -395,7 +402,7 @@ specified by \",fix\".  Keywords without related expressions are ignored."
                                          "unrecognized comma command"
                                          ",help"))
                             (loop "" psql-repl-prompt)))))
-                  ((string=? (substring line (1- len) len) ";")
+                  ((string-suffix? ";" line)
                    line)
                   (else
                    (loop (string-append line " ")
@@ -418,8 +425,8 @@ specified by \",fix\".  Keywords without related expressions are ignored."
                     (pg-print res (pg-make-print-options
                                    '((field-sep . " | "))))
                     (let ((msg (pg-result-error-message res)))
-                (display status) (newline)
-                  (or (string-null? msg)
+                      (display status) (newline)
+                      (or (string-null? msg)
                           (begin (display msg) (newline)))))))
              ((--for-display res)
               (letrec ((out (lambda (x)
