@@ -1,6 +1,6 @@
 ;;; large.scm
 
-;; Copyright (C) 2002-2011, 2014 Thien-Thi Nguyen
+;; Copyright (C) 2002-2011, 2014, 2017, 2019 Thien-Thi Nguyen
 ;; Portions Copyright (C) 1999, 2000 Ian Grant
 ;;
 ;; This file is part of Guile-PG.
@@ -138,17 +138,6 @@
               (set! *N* (pg-lo-get-oid lo-port))
               (close-port lo-port)))))))
 
-(define test:lo-read
-  (add-test #t
-    (lambda ()
-      (transaction
-       (let ((lo-port (pg-lo-open *C* *N* "r"))
-             (data #f))
-         (and lo-port
-              (set! data (pg-lo-read 1 nchars lo-port))
-              (close-port lo-port)
-              (equal? data (make-string nchars #\a))))))))
-
 (define test:read-line
   (add-test #t
     (lambda ()
@@ -179,7 +168,7 @@
               (pg-untrace *C*)
               (close-port trace-port)))))))
 
-;; Test pg-lo-seek pg-lo-read
+;; Test pg-lo-seek
 ;; expect "ababaa"
 
 (define test:lo-seek2
@@ -188,8 +177,27 @@
       (transaction
        (let ((lo-port (pg-lo-open *C* *N* "r"))
              (data #f))
+
+         (define (read-string count)
+           (let loop ((acc '()) (still count))
+             (if (zero? still)
+                 (apply string (reverse! acc))
+                 (loop (cons (read-char lo-port)
+                             acc)
+                       (1- still)))))
+
          (and lo-port
-              (set! data (pg-lo-read 1 6 lo-port))
+              (let ((gone (pg-lo-seek lo-port 42 SEEK_CUR))
+                    (four (read-string 4))
+                    (back (pg-lo-seek lo-port 0 SEEK_SET)))
+                (and (eq? 42 gone)
+                     (string? four)
+                     (string=? "aaaa" four)
+                     (eq? 0 back)))
+              (let ((s (drain-input lo-port)))
+                (and (string? s)
+                     (not (zero? (string-length s)))))
+              (set! data (read-string 6))
               (close-port lo-port)
               data))))))
 
@@ -200,10 +208,9 @@
        (let ((lo-port (pg-lo-open *C* *N* "r")))
          (and lo-port
               (eq? 0 (pg-lo-tell lo-port))
-              (let ((data (pg-lo-read 1 1 lo-port)))
-                (and (string? data)
-                     (= 1 (string-length data))
-                     (string=? "a" data)))
+              (let ((data (read-char lo-port)))
+                (and (char? data)
+                     (char=? #\a data)))
               (let ((location-after-read (pg-lo-tell lo-port)))
                 (eq? 1 (pg-lo-seek lo-port 0 SEEK_CUR))
                 (close-port lo-port)
@@ -217,7 +224,7 @@
 
 (define (main)
   (set! verbose #t)
-  (test-init "large" 13)
+  (test-init "large" 12)
   (test! test:make-connection
          test:make-data
          test:make-table
@@ -225,7 +232,6 @@
          test:lo-export
          test:lo-open-read
          test:lo-creat
-         test:lo-read
          test:read-line
          test:lo-seek
          test:lo-seek2
