@@ -1,4 +1,4 @@
-;; Copyright (C) 2004, 2006, 2008, 2011, 2012 Thien-Thi Nguyen
+;; Copyright (C) 2004, 2006, 2008, 2011, 2012, 2014 Thien-Thi Nguyen
 ;; Copyright (C) 1996, 1997, 1998 Per Bothner.
 ;;
 ;; Usage:
@@ -184,49 +184,29 @@
 
 ;;; Common bits
 
-(define (fs s . args)
-  (apply simple-format #f s args))
+(use-modules (guile-baux common))
+(use-modules (srfi srfi-13))
 
-(define (d/c action severity)
-  (let* ((dbname (or (getenv "PGDATABASE")
-                     (error "Env var PGDATABASE not set.")))
-         (conn (pg-connectdb "dbname=template1"))
-         (res (pg-exec conn (fs "~A DATABASE ~A~A;"
-                                action dbname
-                                (if (equal? "CREATE" action)
-                                    " WITH ENCODING = 'UTF8'"
-                                    ""))))
-         (ok? (eq? 'PGRES_COMMAND_OK (pg-result-status res))))
-    (and (equal? "1" (getenv "DEBUG"))
-         (display (fs "~A: ~A ~A\n"
-                      (if ok? "INFO" severity)
-                      action
-                      (if ok? "ok" (pg-result-error-message res)))))
-    (set! res #f)
-    (pg-finish conn)
-    (set! conn #f)
-    (gc)
-    ok?))
+(define (env-1? var)
+  (equal? "1" (getenv var)))
 
-(define (drop! . no-worries)
-  ;; Give PostgreSQL some time to finish accessing (internally) template1.
-  (usleep 100000)
-  (d/c "DROP" "NO-WORRIES")
-  #t)
-
-(define (fresh!)
-  (drop!)
-  ;; If PostgreSQL has not yet finished accessing (internally) template1
-  ;; (even though it should have), wait a little bit and try again.
-  (cond (                       (d/c "CREATE" "TOO-EAGER"))
-        ((begin (usleep 100000) (d/c "CREATE" "FATAL")))
-        (else (display "ERROR: fresh! failed. Giving up.\n")
-              (exit #f))))
+(define (temp-table-command name . col-defs)
+  (fs "CREATE TEMP TABLE ~A (~A)"
+      name
+      (string-join (map (lambda (spec)
+                          (fs "~S ~A"
+                              (symbol->string (car spec))
+                              (cadr spec)))
+                        col-defs)
+                   ", ")))
 
 
 ;;; load-time actions
 
-(cond ((getenv "DEBUG")
+(cond ((env-1? "DEBUG")
        (set! %load-verbosely #t)))
 
+(or (env-1? "VERBOSE")
+    (set-current-output-port (open-output-file *null-device*)))
+
 ;;; testing.scm ends here
